==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/NieobecnoscInformacja.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class NieobecnoscInformacja extends GenericDPSObject {
    /**
     * NIEOBECNOSC_INFORMACJA.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * NIEOBECNOSC_INFORMACJA.DYZUR_POWROT_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dyzurPowrotId;

    /**
     * NIEOBECNOSC_INFORMACJA.DYZUR_WYJAZD_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long dyzurWyjazdId;

    /**
     * NIEOBECNOSC_INFORMACJA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long ewidencjaDpsId;

    /**
     * NIEOBECNOSC_INFORMACJA.MIEJSCE_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long miejsceId;

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_PRZYJAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikPrzyjalId;

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_SKIEROWAL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikSkierowalId;

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_WPROWADZIL_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long pracownikWprowadzilId;

    /**
     * NIEOBECNOSC_INFORMACJA.DATA_POWROTU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataPowrotu;

    /**
     * NIEOBECNOSC_INFORMACJA.DATA_WYJAZDU
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataWyjazdu;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NIEOBECNOSC_INFORMACJA.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.DYZUR_POWROT_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDyzurPowrotId() {
        return dyzurPowrotId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.DYZUR_POWROT_ID
     *
     * @param dyzurPowrotId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDyzurPowrotId(Long dyzurPowrotId) {
        this.dyzurPowrotId = dyzurPowrotId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.DYZUR_WYJAZD_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getDyzurWyjazdId() {
        return dyzurWyjazdId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.DYZUR_WYJAZD_ID
     *
     * @param dyzurWyjazdId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDyzurWyjazdId(Long dyzurWyjazdId) {
        this.dyzurWyjazdId = dyzurWyjazdId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.MIEJSCE_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getMiejsceId() {
        return miejsceId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.MIEJSCE_ID
     *
     * @param miejsceId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiejsceId(Long miejsceId) {
        this.miejsceId = miejsceId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.PRACOWNIK_PRZYJAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikPrzyjalId() {
        return pracownikPrzyjalId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_PRZYJAL_ID
     *
     * @param pracownikPrzyjalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikPrzyjalId(Long pracownikPrzyjalId) {
        this.pracownikPrzyjalId = pracownikPrzyjalId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.PRACOWNIK_SKIEROWAL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikSkierowalId() {
        return pracownikSkierowalId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_SKIEROWAL_ID
     *
     * @param pracownikSkierowalId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikSkierowalId(Long pracownikSkierowalId) {
        this.pracownikSkierowalId = pracownikSkierowalId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.PRACOWNIK_WPROWADZIL_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getPracownikWprowadzilId() {
        return pracownikWprowadzilId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_WPROWADZIL_ID
     *
     * @param pracownikWprowadzilId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setPracownikWprowadzilId(Long pracownikWprowadzilId) {
        this.pracownikWprowadzilId = pracownikWprowadzilId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.DATA_POWROTU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataPowrotu() {
        return dataPowrotu;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.DATA_POWROTU
     *
     * @param dataPowrotu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataPowrotu(Date dataPowrotu) {
        this.dataPowrotu = dataPowrotu;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.DATA_WYJAZDU
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataWyjazdu() {
        return dataWyjazdu;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.DATA_WYJAZDU
     *
     * @param dataWyjazdu
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataWyjazdu(Date dataWyjazdu) {
        this.dataWyjazdu = dataWyjazdu;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        NieobecnoscInformacja other = (NieobecnoscInformacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDyzurPowrotId() == null ? other.getDyzurPowrotId() == null : this.getDyzurPowrotId().equals(other.getDyzurPowrotId()))
            && (this.getDyzurWyjazdId() == null ? other.getDyzurWyjazdId() == null : this.getDyzurWyjazdId().equals(other.getDyzurWyjazdId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getMiejsceId() == null ? other.getMiejsceId() == null : this.getMiejsceId().equals(other.getMiejsceId()))
            && (this.getPracownikPrzyjalId() == null ? other.getPracownikPrzyjalId() == null : this.getPracownikPrzyjalId().equals(other.getPracownikPrzyjalId()))
            && (this.getPracownikSkierowalId() == null ? other.getPracownikSkierowalId() == null : this.getPracownikSkierowalId().equals(other.getPracownikSkierowalId()))
            && (this.getPracownikWprowadzilId() == null ? other.getPracownikWprowadzilId() == null : this.getPracownikWprowadzilId().equals(other.getPracownikWprowadzilId()))
            && (this.getDataPowrotu() == null ? other.getDataPowrotu() == null : this.getDataPowrotu().equals(other.getDataPowrotu()))
            && (this.getDataWyjazdu() == null ? other.getDataWyjazdu() == null : this.getDataWyjazdu().equals(other.getDataWyjazdu()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDyzurPowrotId() == null) ? 0 : getDyzurPowrotId().hashCode());
        result = prime * result + ((getDyzurWyjazdId() == null) ? 0 : getDyzurWyjazdId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getMiejsceId() == null) ? 0 : getMiejsceId().hashCode());
        result = prime * result + ((getPracownikPrzyjalId() == null) ? 0 : getPracownikPrzyjalId().hashCode());
        result = prime * result + ((getPracownikSkierowalId() == null) ? 0 : getPracownikSkierowalId().hashCode());
        result = prime * result + ((getPracownikWprowadzilId() == null) ? 0 : getPracownikWprowadzilId().hashCode());
        result = prime * result + ((getDataPowrotu() == null) ? 0 : getDataPowrotu().hashCode());
        result = prime * result + ((getDataWyjazdu() == null) ? 0 : getDataWyjazdu().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dyzurPowrotId=").append(dyzurPowrotId);
        sb.append(", dyzurWyjazdId=").append(dyzurWyjazdId);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", miejsceId=").append(miejsceId);
        sb.append(", pracownikPrzyjalId=").append(pracownikPrzyjalId);
        sb.append(", pracownikSkierowalId=").append(pracownikSkierowalId);
        sb.append(", pracownikWprowadzilId=").append(pracownikWprowadzilId);
        sb.append(", dataPowrotu=").append(dataPowrotu);
        sb.append(", dataWyjazdu=").append(dataWyjazdu);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/NieobecnoscInformacja.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class NieobecnoscInformacja extends GenericDPSObject {
    /**
     * NIEOBECNOSC_INFORMACJA.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * NIEOBECNOSC_INFORMACJA.DYZUR_POWROT_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dyzurPowrotId;

    /**
     * NIEOBECNOSC_INFORMACJA.DYZUR_WYJAZD_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long dyzurWyjazdId;

    /**
     * NIEOBECNOSC_INFORMACJA.EWIDENCJA_DPS_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long ewidencjaDpsId;

    /**
     * NIEOBECNOSC_INFORMACJA.MIEJSCE_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long miejsceId;

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_PRZYJAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikPrzyjalId;

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_SKIEROWAL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikSkierowalId;

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_WPROWADZIL_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long pracownikWprowadzilId;

    /**
     * NIEOBECNOSC_INFORMACJA.DATA_POWROTU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataPowrotu;

    /**
     * NIEOBECNOSC_INFORMACJA.DATA_WYJAZDU
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataWyjazdu;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return NIEOBECNOSC_INFORMACJA.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.DYZUR_POWROT_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDyzurPowrotId() {
        return dyzurPowrotId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.DYZUR_POWROT_ID
     *
     * @param dyzurPowrotId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDyzurPowrotId(Long dyzurPowrotId) {
        this.dyzurPowrotId = dyzurPowrotId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.DYZUR_WYJAZD_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getDyzurWyjazdId() {
        return dyzurWyjazdId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.DYZUR_WYJAZD_ID
     *
     * @param dyzurWyjazdId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDyzurWyjazdId(Long dyzurWyjazdId) {
        this.dyzurWyjazdId = dyzurWyjazdId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.EWIDENCJA_DPS_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getEwidencjaDpsId() {
        return ewidencjaDpsId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.EWIDENCJA_DPS_ID
     *
     * @param ewidencjaDpsId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setEwidencjaDpsId(Long ewidencjaDpsId) {
        this.ewidencjaDpsId = ewidencjaDpsId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.MIEJSCE_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getMiejsceId() {
        return miejsceId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.MIEJSCE_ID
     *
     * @param miejsceId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiejsceId(Long miejsceId) {
        this.miejsceId = miejsceId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.PRACOWNIK_PRZYJAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikPrzyjalId() {
        return pracownikPrzyjalId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_PRZYJAL_ID
     *
     * @param pracownikPrzyjalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikPrzyjalId(Long pracownikPrzyjalId) {
        this.pracownikPrzyjalId = pracownikPrzyjalId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.PRACOWNIK_SKIEROWAL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikSkierowalId() {
        return pracownikSkierowalId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_SKIEROWAL_ID
     *
     * @param pracownikSkierowalId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikSkierowalId(Long pracownikSkierowalId) {
        this.pracownikSkierowalId = pracownikSkierowalId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.PRACOWNIK_WPROWADZIL_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getPracownikWprowadzilId() {
        return pracownikWprowadzilId;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.PRACOWNIK_WPROWADZIL_ID
     *
     * @param pracownikWprowadzilId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setPracownikWprowadzilId(Long pracownikWprowadzilId) {
        this.pracownikWprowadzilId = pracownikWprowadzilId;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.DATA_POWROTU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataPowrotu() {
        return dataPowrotu;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.DATA_POWROTU
     *
     * @param dataPowrotu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataPowrotu(Date dataPowrotu) {
        this.dataPowrotu = dataPowrotu;
    }

    /**
     * @return NIEOBECNOSC_INFORMACJA.DATA_WYJAZDU
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataWyjazdu() {
        return dataWyjazdu;
    }

    /**
     * NIEOBECNOSC_INFORMACJA.DATA_WYJAZDU
     *
     * @param dataWyjazdu
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataWyjazdu(Date dataWyjazdu) {
        this.dataWyjazdu = dataWyjazdu;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        NieobecnoscInformacja other = (NieobecnoscInformacja) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getDyzurPowrotId() == null ? other.getDyzurPowrotId() == null : this.getDyzurPowrotId().equals(other.getDyzurPowrotId()))
            && (this.getDyzurWyjazdId() == null ? other.getDyzurWyjazdId() == null : this.getDyzurWyjazdId().equals(other.getDyzurWyjazdId()))
            && (this.getEwidencjaDpsId() == null ? other.getEwidencjaDpsId() == null : this.getEwidencjaDpsId().equals(other.getEwidencjaDpsId()))
            && (this.getMiejsceId() == null ? other.getMiejsceId() == null : this.getMiejsceId().equals(other.getMiejsceId()))
            && (this.getPracownikPrzyjalId() == null ? other.getPracownikPrzyjalId() == null : this.getPracownikPrzyjalId().equals(other.getPracownikPrzyjalId()))
            && (this.getPracownikSkierowalId() == null ? other.getPracownikSkierowalId() == null : this.getPracownikSkierowalId().equals(other.getPracownikSkierowalId()))
            && (this.getPracownikWprowadzilId() == null ? other.getPracownikWprowadzilId() == null : this.getPracownikWprowadzilId().equals(other.getPracownikWprowadzilId()))
            && (this.getDataPowrotu() == null ? other.getDataPowrotu() == null : this.getDataPowrotu().equals(other.getDataPowrotu()))
            && (this.getDataWyjazdu() == null ? other.getDataWyjazdu() == null : this.getDataWyjazdu().equals(other.getDataWyjazdu()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getDyzurPowrotId() == null) ? 0 : getDyzurPowrotId().hashCode());
        result = prime * result + ((getDyzurWyjazdId() == null) ? 0 : getDyzurWyjazdId().hashCode());
        result = prime * result + ((getEwidencjaDpsId() == null) ? 0 : getEwidencjaDpsId().hashCode());
        result = prime * result + ((getMiejsceId() == null) ? 0 : getMiejsceId().hashCode());
        result = prime * result + ((getPracownikPrzyjalId() == null) ? 0 : getPracownikPrzyjalId().hashCode());
        result = prime * result + ((getPracownikSkierowalId() == null) ? 0 : getPracownikSkierowalId().hashCode());
        result = prime * result + ((getPracownikWprowadzilId() == null) ? 0 : getPracownikWprowadzilId().hashCode());
        result = prime * result + ((getDataPowrotu() == null) ? 0 : getDataPowrotu().hashCode());
        result = prime * result + ((getDataWyjazdu() == null) ? 0 : getDataWyjazdu().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", dyzurPowrotId=").append(dyzurPowrotId);
        sb.append(", dyzurWyjazdId=").append(dyzurWyjazdId);
        sb.append(", ewidencjaDpsId=").append(ewidencjaDpsId);
        sb.append(", miejsceId=").append(miejsceId);
        sb.append(", pracownikPrzyjalId=").append(pracownikPrzyjalId);
        sb.append(", pracownikSkierowalId=").append(pracownikSkierowalId);
        sb.append(", pracownikWprowadzilId=").append(pracownikWprowadzilId);
        sb.append(", dataPowrotu=").append(dataPowrotu);
        sb.append(", dataWyjazdu=").append(dataWyjazdu);
        sb.append("]");
        return sb.toString();
    }
}
